@@ -29,11 +29,13 @@ import org.apache.flume.Context;
 import org.apache.flume.Event;
 import org.apache.flume.EventDeliveryException;
 import org.apache.flume.Transaction;
+import org.apache.flume.conf.BatchSizeSupported;
 import org.apache.flume.conf.Configurable;
 import org.apache.flume.conf.ConfigurationException;
 import org.apache.flume.conf.LogPrivacyUtil;
 import org.apache.flume.formatter.output.BucketPath;
 import org.apache.flume.instrumentation.kafka.KafkaSinkCounter;
+import org.apache.flume.shared.kafka.KafkaSSLUtil;
 import org.apache.flume.sink.AbstractSink;
 import org.apache.flume.source.avro.AvroFlumeEvent;
 import org.apache.kafka.clients.producer.Callback;
@@ -70,7 +72,6 @@ import static org.apache.flume.sink.kafka.KafkaSinkConstants.TOPIC_CONFIG;
 import static org.apache.flume.sink.kafka.KafkaSinkConstants.KEY_SERIALIZER_KEY;
 import static org.apache.flume.sink.kafka.KafkaSinkConstants.MESSAGE_SERIALIZER_KEY;
 
-
 /**
  * A Flume Sink that can publish messages to Kafka.
  * This is a general implementation that can be used with any Flume agent and
@@ -102,7 +103,7 @@ import static org.apache.flume.sink.kafka.KafkaSinkConstants.MESSAGE_SERIALIZER_
  * topic
  * key
  */
-public class KafkaSink extends AbstractSink implements Configurable {
+public class KafkaSink extends AbstractSink implements Configurable, BatchSizeSupported {
 
   private static final Logger logger = LoggerFactory.getLogger(KafkaSink.class);
 
@@ -136,7 +137,7 @@ public class KafkaSink extends AbstractSink implements Configurable {
     return topic;
   }
 
-  public int getBatchSize() {
+  public long getBatchSize() {
     return batchSize;
   }
 
@@ -170,6 +171,7 @@ public class KafkaSink extends AbstractSink implements Configurable {
           }
           break;
         }
+        counter.incrementEventDrainAttemptCount();
 
         byte[] eventBody = event.getBody();
         Map<String, String> headers = event.getHeaders();
@@ -178,9 +180,9 @@ public class KafkaSink extends AbstractSink implements Configurable {
           eventTopic = headers.get(topicHeader);
           if (eventTopic == null) {
             eventTopic = BucketPath.escapeString(topic, event.getHeaders());
-            logger.debug("{} was set to true but header {} was null. Producing to {}" + 
+            logger.debug("{} was set to true but header {} was null. Producing to {}" +
                 " topic instead.",
-                new Object[]{KafkaSinkConstants.ALLOW_TOPIC_OVERRIDE_HEADER, 
+                new Object[]{KafkaSinkConstants.ALLOW_TOPIC_OVERRIDE_HEADER,
                     topicHeader, eventTopic});
           }
         } else {
@@ -250,6 +252,7 @@ public class KafkaSink extends AbstractSink implements Configurable {
     } catch (Exception ex) {
       String errorMsg = "Failed to publish events";
       logger.error("Failed to publish events", ex);
+      counter.incrementEventWriteOrChannelFail(ex);
       result = Status.BACKOFF;
       if (transaction != null) {
         try {
@@ -418,6 +421,8 @@ public class KafkaSink extends AbstractSink implements Configurable {
     kafkaProps.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, DEFAULT_VALUE_SERIAIZER);
     kafkaProps.putAll(context.getSubProperties(KAFKA_PRODUCER_PREFIX));
     kafkaProps.put(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG, bootStrapServers);
+
+    KafkaSSLUtil.addGlobalSSLParameters(kafkaProps);
   }
 
   protected Properties getKafkaProps() {
