@@ -55,6 +55,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -183,8 +184,15 @@ public class TestKafkaSink {
     ConsumerRecords recs = pollConsumerRecords(topic);
     assertNotNull(recs);
     assertTrue(recs.count() > 0);
-    ConsumerRecord consumerRecord = (ConsumerRecord) recs.iterator().next();
-    assertEquals(msg, consumerRecord.value());
+    Iterator<ConsumerRecord> iter = recs.records(topic).iterator();
+    boolean match = false;
+    while (iter.hasNext()) {
+      if (msg.equals(iter.next().value())) {
+        match = true;
+        break;
+      }
+    }
+    assertTrue("No message matches " + msg, match);
   }
 
   @Test
@@ -412,6 +420,8 @@ public class TestKafkaSink {
     return pollConsumerRecords(topic, 20);
   }
 
+  // Note that the topic parameter is completely ignored. If the consumer is subscribed to
+  // multiple topics records for all of them will be returned.
   private ConsumerRecords<String, String> pollConsumerRecords(String topic, int maxIter) {
     ConsumerRecords<String, String> recs = null;
     for (int i = 0; i < maxIter; i++) {
