@@ -19,7 +19,6 @@ package org.apache.flume.source.kafka;
 
 import com.google.common.base.Charsets;
 import com.google.common.collect.Lists;
-import junit.framework.Assert;
 
 import kafka.zk.KafkaZkClient;
 import org.apache.avro.io.BinaryEncoder;
@@ -34,6 +33,7 @@ import org.apache.flume.FlumeException;
 import org.apache.flume.PollableSource.Status;
 import org.apache.flume.channel.ChannelProcessor;
 import org.apache.flume.instrumentation.SourceCounter;
+import org.apache.flume.lifecycle.LifecycleState;
 import org.apache.flume.source.avro.AvroFlumeEvent;
 import org.apache.kafka.clients.consumer.ConsumerConfig;
 import org.apache.kafka.clients.consumer.ConsumerRecords;
@@ -50,6 +50,7 @@ import org.apache.kafka.common.serialization.StringDeserializer;
 import org.apache.kafka.common.utils.Time;
 import org.junit.After;
 import org.junit.AfterClass;
+import org.junit.Assert;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -65,6 +66,7 @@ import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.time.Duration;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -340,6 +342,8 @@ public class TestKafkaSource {
     startKafkaSource();
     Thread.sleep(500L);
 
+    assertEquals(LifecycleState.START, kafkaSource.getLifecycleState());
+
     Status status = kafkaSource.process();
     assertEquals(Status.BACKOFF, status);
   }
@@ -703,8 +707,18 @@ public class TestKafkaSource {
     context.put(OLD_GROUP_ID, "old.groupId");
     KafkaSource source = new KafkaSource();
     source.doConfigure(context);
-    String bootstrapServers = source.getBootstrapServers();
-    Assert.assertEquals(kafkaServer.getBootstrapServers(), bootstrapServers);
+    String sourceServers = source.getBootstrapServers();
+    sourceServers = sourceServers.substring(0, sourceServers.indexOf(':'));
+
+    String kafkaServers = kafkaServer.getBootstrapServers();
+    kafkaServers = kafkaServers.substring(0, kafkaServers.indexOf(':'));
+
+    List<String> possibleValues = Arrays.asList("localhost", "127.0.0.1");
+
+    if (!(possibleValues.contains(sourceServers) && possibleValues.contains(kafkaServers))) {
+      fail("Expected either 'localhost' or '127.0.0.1'. Source: "
+              + sourceServers + ", Kafka: " + kafkaServers);
+    }
   }
 
   @Test
@@ -845,7 +859,7 @@ public class TestKafkaSource {
     kafkaSource.stop();
   }
 
-  public void doTestMigrateZookeeperOffsets(boolean hasZookeeperOffsets, boolean hasKafkaOffsets,
+  private void doTestMigrateZookeeperOffsets(boolean hasZookeeperOffsets, boolean hasKafkaOffsets,
                                             String group) throws Exception {
     // create a topic with 1 partition for simplicity
     String topic = findUnusedTopic();
@@ -877,8 +891,8 @@ public class TestKafkaSource {
     // Commit 10th offset to zookeeper
     if (hasZookeeperOffsets) {
       KafkaZkClient zkClient = KafkaZkClient.apply(kafkaServer.getZkConnectString(),
-              JaasUtils.isZkSecurityEnabled(), 30000, 30000, 10, Time.SYSTEM,
-              "kafka.server", "SessionExpireListener");
+              JaasUtils.isZkSaslEnabled(), 30000, 30000, 10, Time.SYSTEM,
+              "kafka.server", "SessionExpireListener", scala.Option.empty(), scala.Option.empty());
       zkClient.getConsumerOffset(group, new TopicPartition(topic, 0));
       Long offset = tenthOffset + 1;
       zkClient.setOrCreateConsumerOffset(group, new TopicPartition(topic, 0), offset);
@@ -928,6 +942,27 @@ public class TestKafkaSource {
     }
   }
 
+  @Test
+  public void testMigrateZookeeperOffsetsWhenTopicNotExists() throws Exception {
+    String topic = findUnusedTopic();
+
+    Context context = prepareDefaultContext("testMigrateOffsets-nonExistingTopic");
+    context.put(ZOOKEEPER_CONNECT_FLUME_KEY, kafkaServer.getZkConnectString());
+    context.put(TOPIC, topic);
+    KafkaSource source = new KafkaSource();
+    source.doConfigure(context);
+
+    source.setChannelProcessor(createGoodChannel());
+    source.start();
+
+    assertEquals(LifecycleState.START, source.getLifecycleState());
+
+    Status status = source.process();
+    assertEquals(Status.BACKOFF, status);
+
+    source.stop();
+  }
+
   ChannelProcessor createGoodChannel() {
 
     ChannelProcessor channelProcessor = mock(ChannelProcessor.class);
